@@ -50,9 +50,13 @@
 //! starting index is a multiple of the compression factor. For example a byte-aligned [`T3B1`]
 //! buffer will always start on an index of the *original* buffer that is a multiple of 3.
 
+#![cfg_attr(not(feature = "std"), no_std)]
+#![cfg_attr(doc_cfg, feature(doc_cfg))]
 #![deny(missing_docs)]
 
-use std::slice;
+extern crate alloc;
+
+use core::slice;
 
 /// Utility functions for encoding and decoding B1T6 encoding.
 pub mod b1t6;
@@ -75,23 +79,22 @@ pub mod trit;
 /// Types and traits used to represent trytes and buffers of trytes.
 pub mod tryte;
 
-#[cfg(feature = "serde1")]
+#[cfg(feature = "serde")]
 mod serde;
 
-use crate::raw::{RawEncoding, RawEncodingBuf};
-use std::{
+use alloc::borrow::ToOwned;
+use core::{
     any,
     borrow::{Borrow, BorrowMut},
     cmp::Ordering,
-    convert::TryFrom,
-    error, fmt, hash,
-    iter::FromIterator,
+    fmt, hash,
     ops::{
         Deref, DerefMut, Index, IndexMut, Neg, Range, RangeFrom, RangeFull, RangeInclusive, RangeTo, RangeToInclusive,
     },
 };
 
-pub use crate::{
+use self::raw::{RawEncoding, RawEncodingBuf};
+pub use self::{
     t1b1::{T1B1Buf, T1B1},
     t2b1::{T2B1Buf, T2B1},
     t3b1::{T3B1Buf, T3B1},
@@ -116,7 +119,8 @@ impl fmt::Display for Error {
     }
 }
 
-impl error::Error for Error {}
+#[cfg(feature = "std")]
+impl std::error::Error for Error {}
 
 /// A type that represents a buffer of trits of unknown length.
 ///
@@ -136,7 +140,7 @@ where
         unsafe { &*(T::empty() as *const _ as *const Self) }
     }
 
-    /// Interpret an (`std::i8`) slice as a trit slice with the given encoding without first
+    /// Interpret an (`core::i8`) slice as a trit slice with the given encoding without first
     /// checking that the slice is valid in the given encoding. The `num_trits` parameter is used
     /// to specify the exact length, in trits, that the slice should be taken to have. Providing a
     /// slice that is not valid for this encoding is undefined behaviour.
@@ -160,7 +164,7 @@ where
         &*(T::from_raw_unchecked(raw, num_trits) as *const _ as *const _)
     }
 
-    /// Interpret a mutable (`std::i8`) slice as a mutable trit slice with the given encoding
+    /// Interpret a mutable (`core::i8`) slice as a mutable trit slice with the given encoding
     /// without first checking that the slice is valid in the given encoding. The `num_trits`
     /// parameter is used to specify the exact length, in trits, that the slice should be taken to
     /// have. Providing a slice that is not valid for this encoding is undefined behaviour.
@@ -184,7 +188,7 @@ where
         &mut *(T::from_raw_unchecked_mut(raw, num_trits) as *mut _ as *mut _)
     }
 
-    /// Interpret an (`std::i8`) slice as a trit slice with the given encoding, checking to ensure
+    /// Interpret an (`core::i8`) slice as a trit slice with the given encoding, checking to ensure
     /// that the slice is valid in the given encoding. The `num_trits` parameter is used to specify
     /// the exact length, in trits, that the slice should be taken to have.
     ///
@@ -200,7 +204,7 @@ where
         }
     }
 
-    /// Interpret a mutable (`std::i8`) slice as a mutable trit slice with the given encoding,
+    /// Interpret a mutable (`core::i8`) slice as a mutable trit slice with the given encoding,
     /// checking to ensure that the slice is valid in the given encoding. The `num_trits` parameter
     /// is used to specify the exact length, in trits, that the slice should be taken to have.
     ///
@@ -226,7 +230,7 @@ where
         self.0.len()
     }
 
-    /// Interpret this slice as an (`std::i8`) slice.
+    /// Interpret this slice as an (`core::i8`) slice.
     ///
     /// # Panics
     ///
@@ -235,7 +239,7 @@ where
         self.0.as_i8_slice()
     }
 
-    /// Interpret this slice as a mutable (`std::i8`) slice.
+    /// Interpret this slice as a mutable (`core::i8`) slice.
     ///
     /// # Panics
     ///
@@ -715,8 +719,8 @@ impl<T: RawEncoding + ?Sized> fmt::Display for Trits<T> {
 
 /// A buffer containing trits.
 ///
-/// This type is roughly analogous to [`Vec`] or [`String`]. It supports pushing and popping trits
-/// and dereferences to [`Trits`]. It may be borrowed as a trit slice, either mutably or immutably.
+/// This type is roughly analogous to [`Vec`](alloc::vec::Vec) or [`String`](alloc::string::String). It supports pushing
+/// and popping trits and dereferences to [`Trits`]. It may be borrowed as a trit slice, either mutably or immutably.
 #[derive(Clone)]
 #[repr(transparent)]
 pub struct TritBuf<T: RawEncodingBuf = T1B1Buf<Btrit>>(T);
@@ -791,6 +795,11 @@ impl<T: RawEncodingBuf> TritBuf<T> {
     pub fn as_slice_mut(&mut self) -> &mut Trits<T::Slice> {
         unsafe { &mut *(self.0.as_slice_mut() as *mut T::Slice as *mut Trits<T::Slice>) }
     }
+
+    /// Returns the number of trits the `TritBuf` can hold without reallocating.
+    pub fn capacity(&self) -> usize {
+        self.0.capacity()
+    }
 }
 
 impl TritBuf<T3B1Buf> {
@@ -806,6 +815,7 @@ impl TritBuf<T3B1Buf> {
     /// Pad the trit buffer with [`Btrit::Zero`] until the buffer's length is a multiple of 3.
     ///
     /// This method is often used in conjunction with [`Trits::as_trytes`].
+    #[must_use]
     pub fn padded_zeros(mut self) -> Self {
         self.pad_zeros();
         self
@@ -818,6 +828,7 @@ where
 {
     type Output = Self;
 
+    #[must_use]
     fn neg(mut self) -> Self {
         self.negate();
         self
